pub struct ChainedClassSequenceRule<'a> {
data: FontData<'a>,
}Expand description
Part of ChainedSequenceContextFormat2
Fields
data: FontData<'a>Implementations
Sourceimpl ChainedClassSequenceRule<'_>
impl ChainedClassSequenceRule<'_>
Sourceimpl<'a> ChainedClassSequenceRule<'a>
impl<'a> ChainedClassSequenceRule<'a>
pub const MIN_SIZE: usize
Sourcepub fn resolve_offset<O: Offset, R: FontRead<'a>>(
&self,
offset: O,
) -> Result<R, ReadError>
pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>
Resolve the provided offset from the start of this table.
Sourcepub fn offset_data(&self) -> FontData<'a>
pub fn offset_data(&self) -> FontData<'a>
Return a reference to this table’s raw data.
We use this in the compile crate to resolve offsets.
Sourcepub fn shape(&self) -> &Self
👎Deprecated: just use the base type directly
pub fn shape(&self) -> &Self
Return a reference to the table’s ‘Shape’ struct.
This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.
Sourcepub fn backtrack_glyph_count(&self) -> u16
pub fn backtrack_glyph_count(&self) -> u16
Number of glyphs in the backtrack sequence
Sourcepub fn backtrack_sequence(&self) -> &'a [BigEndian<u16>]
pub fn backtrack_sequence(&self) -> &'a [BigEndian<u16>]
Array of backtrack-sequence classes
Sourcepub fn input_glyph_count(&self) -> u16
pub fn input_glyph_count(&self) -> u16
Total number of glyphs in the input sequence
Sourcepub fn input_sequence(&self) -> &'a [BigEndian<u16>]
pub fn input_sequence(&self) -> &'a [BigEndian<u16>]
Array of input sequence classes, beginning with the second glyph position
Sourcepub fn lookahead_glyph_count(&self) -> u16
pub fn lookahead_glyph_count(&self) -> u16
Number of glyphs in the lookahead sequence
Sourcepub fn lookahead_sequence(&self) -> &'a [BigEndian<u16>]
pub fn lookahead_sequence(&self) -> &'a [BigEndian<u16>]
Array of lookahead-sequence classes
Sourcepub fn seq_lookup_count(&self) -> u16
pub fn seq_lookup_count(&self) -> u16
Number of SequenceLookupRecords
Sourcepub fn seq_lookup_records(&self) -> &'a [SequenceLookupRecord]
pub fn seq_lookup_records(&self) -> &'a [SequenceLookupRecord]
Array of SequenceLookupRecords
pub fn backtrack_glyph_count_byte_range(&self) -> Range<usize> ⓘ
pub fn backtrack_sequence_byte_range(&self) -> Range<usize> ⓘ
pub fn input_glyph_count_byte_range(&self) -> Range<usize> ⓘ
pub fn input_sequence_byte_range(&self) -> Range<usize> ⓘ
pub fn lookahead_glyph_count_byte_range(&self) -> Range<usize> ⓘ
pub fn lookahead_sequence_byte_range(&self) -> Range<usize> ⓘ
pub fn seq_lookup_count_byte_range(&self) -> Range<usize> ⓘ
pub fn seq_lookup_records_byte_range(&self) -> Range<usize> ⓘ