pub struct ChainedSequenceContextFormat1<'a> {
data: FontData<'a>,
}Expand description
Fields
data: FontData<'a>Implementations
Sourceimpl<'a> ChainedSequenceContextFormat1<'a>
impl<'a> ChainedSequenceContextFormat1<'a>
pub const MIN_SIZE: usize
Sourcepub fn resolve_offset<O: Offset, R: FontRead<'a>>(
&self,
offset: O,
) -> Result<R, ReadError>
pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>
Resolve the provided offset from the start of this table.
Sourcepub fn offset_data(&self) -> FontData<'a>
pub fn offset_data(&self) -> FontData<'a>
Return a reference to this table’s raw data.
We use this in the compile crate to resolve offsets.
Sourcepub fn shape(&self) -> &Self
👎Deprecated: just use the base type directly
pub fn shape(&self) -> &Self
Return a reference to the table’s ‘Shape’ struct.
This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.
Sourcepub fn coverage_offset(&self) -> Offset16
pub fn coverage_offset(&self) -> Offset16
Offset to Coverage table, from beginning of ChainSequenceContextFormat1 table
Sourcepub fn coverage(&self) -> Result<CoverageTable<'a>, ReadError>
pub fn coverage(&self) -> Result<CoverageTable<'a>, ReadError>
Attempt to resolve coverage_offset.
Sourcepub fn chained_seq_rule_set_count(&self) -> u16
pub fn chained_seq_rule_set_count(&self) -> u16
Number of ChainedSequenceRuleSet tables
Sourcepub fn chained_seq_rule_set_offsets(
&self,
) -> &'a [BigEndian<Nullable<Offset16>>]
pub fn chained_seq_rule_set_offsets( &self, ) -> &'a [BigEndian<Nullable<Offset16>>]
Array of offsets to ChainedSeqRuleSet tables, from beginning of ChainedSequenceContextFormat1 table (may be NULL)
Sourcepub fn chained_seq_rule_sets(
&self,
) -> ArrayOfNullableOffsets<'a, ChainedSequenceRuleSet<'a>, Offset16>
pub fn chained_seq_rule_sets( &self, ) -> ArrayOfNullableOffsets<'a, ChainedSequenceRuleSet<'a>, Offset16>
A dynamically resolving wrapper for chained_seq_rule_set_offsets.
pub fn format_byte_range(&self) -> Range<usize> ⓘ
pub fn coverage_offset_byte_range(&self) -> Range<usize> ⓘ
pub fn chained_seq_rule_set_count_byte_range(&self) -> Range<usize> ⓘ
pub fn chained_seq_rule_set_offsets_byte_range(&self) -> Range<usize> ⓘ