pub struct ChainedSequenceContextFormat3<'a> {
data: FontData<'a>,
}Expand description
Fields
data: FontData<'a>Implementations
Sourceimpl<'a> ChainedSequenceContextFormat3<'a>
impl<'a> ChainedSequenceContextFormat3<'a>
pub const MIN_SIZE: usize
Sourcepub fn resolve_offset<O: Offset, R: FontRead<'a>>(
&self,
offset: O,
) -> Result<R, ReadError>
pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>
Resolve the provided offset from the start of this table.
Sourcepub fn offset_data(&self) -> FontData<'a>
pub fn offset_data(&self) -> FontData<'a>
Return a reference to this table’s raw data.
We use this in the compile crate to resolve offsets.
Sourcepub fn shape(&self) -> &Self
👎Deprecated: just use the base type directly
pub fn shape(&self) -> &Self
Return a reference to the table’s ‘Shape’ struct.
This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.
Sourcepub fn backtrack_glyph_count(&self) -> u16
pub fn backtrack_glyph_count(&self) -> u16
Number of glyphs in the backtrack sequence
Sourcepub fn backtrack_coverage_offsets(&self) -> &'a [BigEndian<Offset16>]
pub fn backtrack_coverage_offsets(&self) -> &'a [BigEndian<Offset16>]
Array of offsets to coverage tables for the backtrack sequence
Sourcepub fn backtrack_coverages(
&self,
) -> ArrayOfOffsets<'a, CoverageTable<'a>, Offset16>
pub fn backtrack_coverages( &self, ) -> ArrayOfOffsets<'a, CoverageTable<'a>, Offset16>
A dynamically resolving wrapper for backtrack_coverage_offsets.
Sourcepub fn input_glyph_count(&self) -> u16
pub fn input_glyph_count(&self) -> u16
Number of glyphs in the input sequence
Sourcepub fn input_coverage_offsets(&self) -> &'a [BigEndian<Offset16>]
pub fn input_coverage_offsets(&self) -> &'a [BigEndian<Offset16>]
Array of offsets to coverage tables for the input sequence
Sourcepub fn input_coverages(&self) -> ArrayOfOffsets<'a, CoverageTable<'a>, Offset16>
pub fn input_coverages(&self) -> ArrayOfOffsets<'a, CoverageTable<'a>, Offset16>
A dynamically resolving wrapper for input_coverage_offsets.
Sourcepub fn lookahead_glyph_count(&self) -> u16
pub fn lookahead_glyph_count(&self) -> u16
Number of glyphs in the lookahead sequence
Sourcepub fn lookahead_coverage_offsets(&self) -> &'a [BigEndian<Offset16>]
pub fn lookahead_coverage_offsets(&self) -> &'a [BigEndian<Offset16>]
Array of offsets to coverage tables for the lookahead sequence
Sourcepub fn lookahead_coverages(
&self,
) -> ArrayOfOffsets<'a, CoverageTable<'a>, Offset16>
pub fn lookahead_coverages( &self, ) -> ArrayOfOffsets<'a, CoverageTable<'a>, Offset16>
A dynamically resolving wrapper for lookahead_coverage_offsets.
Sourcepub fn seq_lookup_count(&self) -> u16
pub fn seq_lookup_count(&self) -> u16
Number of SequenceLookupRecords
Sourcepub fn seq_lookup_records(&self) -> &'a [SequenceLookupRecord]
pub fn seq_lookup_records(&self) -> &'a [SequenceLookupRecord]
Array of SequenceLookupRecords
pub fn format_byte_range(&self) -> Range<usize> ⓘ
pub fn backtrack_glyph_count_byte_range(&self) -> Range<usize> ⓘ
pub fn backtrack_coverage_offsets_byte_range(&self) -> Range<usize> ⓘ
pub fn input_glyph_count_byte_range(&self) -> Range<usize> ⓘ
pub fn input_coverage_offsets_byte_range(&self) -> Range<usize> ⓘ
pub fn lookahead_glyph_count_byte_range(&self) -> Range<usize> ⓘ
pub fn lookahead_coverage_offsets_byte_range(&self) -> Range<usize> ⓘ
pub fn seq_lookup_count_byte_range(&self) -> Range<usize> ⓘ
pub fn seq_lookup_records_byte_range(&self) -> Range<usize> ⓘ