pub struct CharacterVariantParams<'a> {
data: FontData<'a>,
}Expand description
featureParams for ‘cv01’-‘cv99’
Fields
data: FontData<'a>Implementations
Sourceimpl<'a> CharacterVariantParams<'a>
impl<'a> CharacterVariantParams<'a>
pub const MIN_SIZE: usize
Sourcepub fn resolve_offset<O: Offset, R: FontRead<'a>>(
&self,
offset: O,
) -> Result<R, ReadError>
pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>
Resolve the provided offset from the start of this table.
Sourcepub fn offset_data(&self) -> FontData<'a>
pub fn offset_data(&self) -> FontData<'a>
Return a reference to this table’s raw data.
We use this in the compile crate to resolve offsets.
Sourcepub fn shape(&self) -> &Self
👎Deprecated: just use the base type directly
pub fn shape(&self) -> &Self
Return a reference to the table’s ‘Shape’ struct.
This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.
Sourcepub fn feat_ui_label_name_id(&self) -> NameId
pub fn feat_ui_label_name_id(&self) -> NameId
The ‘name’ table name ID that specifies a string (or strings, for multiple languages) for a user-interface label for this feature. (May be NULL.)
Sourcepub fn feat_ui_tooltip_text_name_id(&self) -> NameId
pub fn feat_ui_tooltip_text_name_id(&self) -> NameId
The ‘name’ table name ID that specifies a string (or strings, for multiple languages) that an application can use for tooltip text for this feature. (May be NULL.)
Sourcepub fn sample_text_name_id(&self) -> NameId
pub fn sample_text_name_id(&self) -> NameId
The ‘name’ table name ID that specifies sample text that illustrates the effect of this feature. (May be NULL.)
Sourcepub fn num_named_parameters(&self) -> u16
pub fn num_named_parameters(&self) -> u16
Number of named parameters. (May be zero.)
Sourcepub fn first_param_ui_label_name_id(&self) -> NameId
pub fn first_param_ui_label_name_id(&self) -> NameId
The first ‘name’ table name ID used to specify strings for user-interface labels for the feature parameters. (Must be zero if numParameters is zero.)
Sourcepub fn char_count(&self) -> u16
pub fn char_count(&self) -> u16
The count of characters for which this feature provides glyph variants. (May be zero.)
Sourcepub fn character(&self) -> &'a [BigEndian<Uint24>]
pub fn character(&self) -> &'a [BigEndian<Uint24>]
The Unicode Scalar Value of the characters for which this feature provides glyph variants.
pub fn format_byte_range(&self) -> Range<usize> ⓘ
pub fn feat_ui_label_name_id_byte_range(&self) -> Range<usize> ⓘ
pub fn feat_ui_tooltip_text_name_id_byte_range(&self) -> Range<usize> ⓘ
pub fn sample_text_name_id_byte_range(&self) -> Range<usize> ⓘ
pub fn num_named_parameters_byte_range(&self) -> Range<usize> ⓘ
pub fn first_param_ui_label_name_id_byte_range(&self) -> Range<usize> ⓘ
pub fn char_count_byte_range(&self) -> Range<usize> ⓘ
pub fn character_byte_range(&self) -> Range<usize> ⓘ