pub struct ClassDefFormat1<'a> {
data: FontData<'a>,
}Expand description
Fields
data: FontData<'a>Implementations
Sourceimpl<'a> ClassDefFormat1<'a>
impl<'a> ClassDefFormat1<'a>
pub const MIN_SIZE: usize
Sourcepub fn resolve_offset<O: Offset, R: FontRead<'a>>(
&self,
offset: O,
) -> Result<R, ReadError>
pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>
Resolve the provided offset from the start of this table.
Sourcepub fn offset_data(&self) -> FontData<'a>
pub fn offset_data(&self) -> FontData<'a>
Return a reference to this table’s raw data.
We use this in the compile crate to resolve offsets.
Sourcepub fn shape(&self) -> &Self
👎Deprecated: just use the base type directly
pub fn shape(&self) -> &Self
Return a reference to the table’s ‘Shape’ struct.
This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.
Sourcepub fn class_format(&self) -> u16
pub fn class_format(&self) -> u16
Format identifier — format = 1
Sourcepub fn start_glyph_id(&self) -> GlyphId16
pub fn start_glyph_id(&self) -> GlyphId16
First glyph ID of the classValueArray
Sourcepub fn glyph_count(&self) -> u16
pub fn glyph_count(&self) -> u16
Size of the classValueArray
Sourcepub fn class_value_array(&self) -> &'a [BigEndian<u16>]
pub fn class_value_array(&self) -> &'a [BigEndian<u16>]
Array of Class Values — one per glyph ID
pub fn class_format_byte_range(&self) -> Range<usize> ⓘ
pub fn start_glyph_id_byte_range(&self) -> Range<usize> ⓘ
pub fn glyph_count_byte_range(&self) -> Range<usize> ⓘ
pub fn class_value_array_byte_range(&self) -> Range<usize> ⓘ
Sourceimpl<'a> ClassDefFormat1<'a>
impl<'a> ClassDefFormat1<'a>
Sourcepub fn iter(&self) -> impl Iterator<Item = (GlyphId16, u16)> + 'a
pub fn iter(&self) -> impl Iterator<Item = (GlyphId16, u16)> + 'a
Iterate over each glyph and its class.
Sourcepub fn population(&self) -> usize
pub fn population(&self) -> usize
Return the number of glyphs explicitly assigned to a class in this table