pub struct ConditionFormat1<'a> {
data: FontData<'a>,
}Expand description
Condition Table Format 1: Font Variation Axis Range
Fields
data: FontData<'a>Implementations
Sourceimpl<'a> ConditionFormat1<'a>
impl<'a> ConditionFormat1<'a>
pub const MIN_SIZE: usize
Sourcepub fn resolve_offset<O: Offset, R: FontRead<'a>>(
&self,
offset: O,
) -> Result<R, ReadError>
pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>
Resolve the provided offset from the start of this table.
Sourcepub fn offset_data(&self) -> FontData<'a>
pub fn offset_data(&self) -> FontData<'a>
Return a reference to this table’s raw data.
We use this in the compile crate to resolve offsets.
Sourcepub fn shape(&self) -> &Self
👎Deprecated: just use the base type directly
pub fn shape(&self) -> &Self
Return a reference to the table’s ‘Shape’ struct.
This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.
Sourcepub fn axis_index(&self) -> u16
pub fn axis_index(&self) -> u16
Index (zero-based) for the variation axis within the ‘fvar’ table.
Sourcepub fn filter_range_min_value(&self) -> F2Dot14
pub fn filter_range_min_value(&self) -> F2Dot14
Minimum value of the font variation instances that satisfy this condition.
Sourcepub fn filter_range_max_value(&self) -> F2Dot14
pub fn filter_range_max_value(&self) -> F2Dot14
Maximum value of the font variation instances that satisfy this condition.
pub fn format_byte_range(&self) -> Range<usize> ⓘ
pub fn axis_index_byte_range(&self) -> Range<usize> ⓘ
pub fn filter_range_min_value_byte_range(&self) -> Range<usize> ⓘ
pub fn filter_range_max_value_byte_range(&self) -> Range<usize> ⓘ