pub struct CoverageFormat1<'a> {
data: FontData<'a>,
}Expand description
Fields
data: FontData<'a>Implementations
Sourceimpl<'a> CoverageFormat1<'a>
impl<'a> CoverageFormat1<'a>
pub const MIN_SIZE: usize
Sourcepub fn resolve_offset<O: Offset, R: FontRead<'a>>(
&self,
offset: O,
) -> Result<R, ReadError>
pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>
Resolve the provided offset from the start of this table.
Sourcepub fn offset_data(&self) -> FontData<'a>
pub fn offset_data(&self) -> FontData<'a>
Return a reference to this table’s raw data.
We use this in the compile crate to resolve offsets.
Sourcepub fn shape(&self) -> &Self
👎Deprecated: just use the base type directly
pub fn shape(&self) -> &Self
Return a reference to the table’s ‘Shape’ struct.
This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.
Sourcepub fn coverage_format(&self) -> u16
pub fn coverage_format(&self) -> u16
Format identifier — format = 1
Sourcepub fn glyph_count(&self) -> u16
pub fn glyph_count(&self) -> u16
Number of glyphs in the glyph array
Sourcepub fn glyph_array(&self) -> &'a [BigEndian<GlyphId16>]
pub fn glyph_array(&self) -> &'a [BigEndian<GlyphId16>]
Array of glyph IDs — in numerical order
pub fn coverage_format_byte_range(&self) -> Range<usize> ⓘ
pub fn glyph_count_byte_range(&self) -> Range<usize> ⓘ
pub fn glyph_array_byte_range(&self) -> Range<usize> ⓘ
Sourceimpl CoverageFormat1<'_>
impl CoverageFormat1<'_>
Sourcepub fn get(&self, gid: impl Into<GlyphId>) -> Option<u16>
pub fn get(&self, gid: impl Into<GlyphId>) -> Option<u16>
If this glyph is in the coverage table, returns its index
Sourcefn intersects(&self, glyphs: &IntSet<GlyphId>) -> bool
fn intersects(&self, glyphs: &IntSet<GlyphId>) -> bool
Returns if this table contains at least one glyph in the ‘glyphs’ set.
Sourcefn intersect_set(&self, glyphs: &IntSet<GlyphId>) -> IntSet<GlyphId>
fn intersect_set(&self, glyphs: &IntSet<GlyphId>) -> IntSet<GlyphId>
Returns the intersection of this table and input ‘glyphs’ set.
Sourcepub fn population(&self) -> usize
pub fn population(&self) -> usize
Return the number of glyphs in this table