Lookup

Struct Lookup 

pub struct Lookup<'a, T = ()> {
    data: FontData<'a>,
    offset_type: PhantomData<*const T>,
}
Fields

data: FontData<'a>offset_type: PhantomData<*const T>

Implementations

Source

impl<'a> Lookup<'a, ()>

pub(crate) fn into_concrete<T>(self) -> Lookup<'a, T>

Source

impl<'a, T> Lookup<'a, T>

pub(crate) fn of_unit_type(&self) -> Lookup<'a, ()>

Replace the specific generic type on this implementation with ()

Source

impl<'a, T> Lookup<'a, T>

pub const MIN_SIZE: usize

pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>

Resolve the provided offset from the start of this table.

pub fn offset_data(&self) -> FontData<'a>

Return a reference to this table’s raw data.

We use this in the compile crate to resolve offsets.

pub fn shape(&self) -> &Self

👎Deprecated: just use the base type directly

Return a reference to the table’s ‘Shape’ struct.

This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.

pub fn lookup_type(&self) -> u16

Different enumerations for GSUB and GPOS

pub fn lookup_flag(&self) -> LookupFlag

Lookup qualifiers

pub fn sub_table_count(&self) -> u16

Number of subtables for this lookup

pub fn subtable_offsets(&self) -> &'a [BigEndian<Offset16>]

Array of offsets to lookup subtables, from beginning of Lookup table

pub fn subtables(&self) -> ArrayOfOffsets<'a, T, Offset16>
where T: FontRead<'a>,

A dynamically resolving wrapper for subtable_offsets.

pub fn mark_filtering_set(&self) -> Option<u16>

Index (base 0) into GDEF mark glyph sets structure. This field is only present if the USE_MARK_FILTERING_SET lookup flag is set.

pub fn lookup_type_byte_range(&self) -> Range<usize>

pub fn lookup_flag_byte_range(&self) -> Range<usize>

pub fn sub_table_count_byte_range(&self) -> Range<usize>

pub fn subtable_offsets_byte_range(&self) -> Range<usize>

pub fn mark_filtering_set_byte_range(&self) -> Range<usize>

Source

impl<'a, T: FontRead<'a>> Lookup<'a, T>

pub fn get_subtable(&self, offset: Offset16) -> Result<T, ReadError>