pub struct LookupList<'a, T = ()> {
data: FontData<'a>,
offset_type: PhantomData<*const T>,
}Expand description
Fields
data: FontData<'a>offset_type: PhantomData<*const T>Implementations
Sourceimpl LookupList<'_, PositionLookup<'_>>
impl LookupList<'_, PositionLookup<'_>>
Sourceimpl LookupList<'_, SubstitutionLookup<'_>>
impl LookupList<'_, SubstitutionLookup<'_>>
Sourceimpl<'a> LookupList<'a, ()>
impl<'a> LookupList<'a, ()>
pub(crate) fn into_concrete<T>(self) -> LookupList<'a, T>
Sourceimpl<'a, T> LookupList<'a, T>
impl<'a, T> LookupList<'a, T>
Sourcepub(crate) fn of_unit_type(&self) -> LookupList<'a, ()>
pub(crate) fn of_unit_type(&self) -> LookupList<'a, ()>
Replace the specific generic type on this implementation with ()
Sourceimpl<'a, T> LookupList<'a, T>
impl<'a, T> LookupList<'a, T>
pub const MIN_SIZE: usize = u16::RAW_BYTE_LEN
Sourcepub fn resolve_offset<O: Offset, R: FontRead<'a>>(
&self,
offset: O,
) -> Result<R, ReadError>
pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>
Resolve the provided offset from the start of this table.
Sourcepub fn offset_data(&self) -> FontData<'a>
pub fn offset_data(&self) -> FontData<'a>
Return a reference to this table’s raw data.
We use this in the compile crate to resolve offsets.
Sourcepub fn shape(&self) -> &Self
👎Deprecated: just use the base type directly
pub fn shape(&self) -> &Self
Return a reference to the table’s ‘Shape’ struct.
This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.
Sourcepub fn lookup_count(&self) -> u16
pub fn lookup_count(&self) -> u16
Number of lookups in this table
Sourcepub fn lookup_offsets(&self) -> &'a [BigEndian<Offset16>]
pub fn lookup_offsets(&self) -> &'a [BigEndian<Offset16>]
Array of offsets to Lookup tables, from beginning of LookupList — zero based (first lookup is Lookup index = 0)
Sourcepub fn lookups(&self) -> ArrayOfOffsets<'a, T, Offset16>where
T: FontRead<'a>,
pub fn lookups(&self) -> ArrayOfOffsets<'a, T, Offset16>where
T: FontRead<'a>,
A dynamically resolving wrapper for lookup_offsets.
pub fn lookup_count_byte_range(&self) -> Range<usize> ⓘ
pub fn lookup_offsets_byte_range(&self) -> Range<usize> ⓘ