pub struct StylisticSetParams<'a> {
data: FontData<'a>,
}Fields
data: FontData<'a>Implementations
Sourceimpl<'a> StylisticSetParams<'a>
impl<'a> StylisticSetParams<'a>
pub const MIN_SIZE: usize
Sourcepub fn resolve_offset<O: Offset, R: FontRead<'a>>(
&self,
offset: O,
) -> Result<R, ReadError>
pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>
Resolve the provided offset from the start of this table.
Sourcepub fn offset_data(&self) -> FontData<'a>
pub fn offset_data(&self) -> FontData<'a>
Return a reference to this table’s raw data.
We use this in the compile crate to resolve offsets.
Sourcepub fn shape(&self) -> &Self
👎Deprecated: just use the base type directly
pub fn shape(&self) -> &Self
Return a reference to the table’s ‘Shape’ struct.
This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.
pub fn version(&self) -> u16
Sourcepub fn ui_name_id(&self) -> NameId
pub fn ui_name_id(&self) -> NameId
The ‘name’ table name ID that specifies a string (or strings, for multiple languages) for a user-interface label for this feature.
The value of uiLabelNameId is expected to be in the font-specific name ID range (256-32767), though that is not a requirement in this Feature Parameters specification. The user-interface label for the feature can be provided in multiple languages. An English string should be included as a fallback. The string should be kept to a minimal length to fit comfortably with different application interfaces.
pub fn version_byte_range(&self) -> Range<usize> ⓘ
pub fn ui_name_id_byte_range(&self) -> Range<usize> ⓘ