pub struct VariationIndex<'a> {
data: FontData<'a>,
}Expand description
Variation index table
Fields
data: FontData<'a>Implementations
Sourceimpl<'a> VariationIndex<'a>
impl<'a> VariationIndex<'a>
pub const MIN_SIZE: usize
Sourcepub fn resolve_offset<O: Offset, R: FontRead<'a>>(
&self,
offset: O,
) -> Result<R, ReadError>
pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>
Resolve the provided offset from the start of this table.
Sourcepub fn offset_data(&self) -> FontData<'a>
pub fn offset_data(&self) -> FontData<'a>
Return a reference to this table’s raw data.
We use this in the compile crate to resolve offsets.
Sourcepub fn shape(&self) -> &Self
👎Deprecated: just use the base type directly
pub fn shape(&self) -> &Self
Return a reference to the table’s ‘Shape’ struct.
This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.
Sourcepub fn delta_set_outer_index(&self) -> u16
pub fn delta_set_outer_index(&self) -> u16
A delta-set outer index — used to select an item variation data subtable within the item variation store.
Sourcepub fn delta_set_inner_index(&self) -> u16
pub fn delta_set_inner_index(&self) -> u16
A delta-set inner index — used to select a delta-set row within an item variation data subtable.
Sourcepub fn delta_format(&self) -> DeltaFormat
pub fn delta_format(&self) -> DeltaFormat
Format, = 0x8000
pub fn delta_set_outer_index_byte_range(&self) -> Range<usize> ⓘ
pub fn delta_set_inner_index_byte_range(&self) -> Range<usize> ⓘ
pub fn delta_format_byte_range(&self) -> Range<usize> ⓘ